MatchMakerActivation.minimum\_display\_time\_msg
===================================================================

.. currentmodule:: alfred3_interact.page

.. autoproperty:: MatchMakerActivation.minimum_display_time_msg
